/* fe_rw_drv_test.c */

#include <linux/module.h>
#include <linux/kernel.h>
#include <linux/init.h>

MODULE_LICENSE("GPL");

extern void *wan_aftup_te1_global_init(int card_number);
extern int wan_aftup_te1_reg_write(void *card, unsigned short reg, unsigned short in_data);
extern int wan_aftup_te1_reg_read(void *card, unsigned short reg, unsigned char *out_data);


static int fe_rw_drv_init(void)
{
	void *card;
	int card_number = 1; /* In the simplest case there is only one
						  * Sangoma t1/e1 card in the system. */
	unsigned char out_data;
	const unsigned char test_value = 1;

	printk(KERN_INFO "%s()\n", __FUNCTION__);

	/* Run global initialization */
	card = wan_aftup_te1_global_init(card_number);

	if (!card) {
		printk(KERN_INFO "%s(): Error: failed to initialize card '%d'!\n",
			__FUNCTION__, card_number);
		return 1;
	}

	/* As an example, read Chip ID */
	wan_aftup_te1_reg_read(card, 0xF8, &out_data);

	printk(KERN_INFO "%s(): Read[0x%04X] : 0x%02X\n",
		__FUNCTION__, 0xF8, out_data);
	
	/* As an example, write to RCR1 */
	wan_aftup_te1_reg_write(card, 0x81, test_value);

	/* Read the written value. */
	wan_aftup_te1_reg_read(card, 0x81, &out_data);

	/* Compare the read value with the expected one. */
	if (out_data != test_value) {
		printk(KERN_INFO "%s(): Error: Write to 0x81 failed'!\n",
			__FUNCTION__);
	}

	return 0;
}

static void fe_rw_drv_exit(void)
{
	printk(KERN_INFO "%s()\n", __FUNCTION__);
}

module_init(fe_rw_drv_init);
module_exit(fe_rw_drv_exit);

